@@ -1,9 +1,9 @@
 import os
 from setuptools import setup, find_packages
-from avi.version import AVI_PIP_VERSION
 
 # allow setup.py to be run from any path
 os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
+AVI_PIP_VERSION=''
 
 setup(
     name='avinetscalerconverter',
@@ -23,7 +23,7 @@ setup(
     ],
     include_package_data=True,
     install_requires=['pyyaml', 'requests', 'pyparsing', 'paramiko', 'avisdk',
-                      'pycrypto', 'ecdsa'],
+                      'pycrypto', 'ecdsa', 'pyOpenssl'],
     package_data={'avi': ['*.cfg', '*.conf', '*.crt', '*.crl', '*.json',
                           '*.key', '*.pem', '*.xml', '*.yaml']},
 )
